@@ -23,7 +23,7 @@ from pydantic import BaseModel, Field
 
 from rcsb.utils.chem.ChemCompSearchWrapper import ChemCompSearchWrapper
 
-logger = logging.getLogger("app_chem")
+logger = logging.getLogger(__name__)
 
 MatchResults = namedtuple("MatchResults", "ccId oeMol searchType matchOpts screenType fpType fpScore oeIdx formula", defaults=(None,) * 9)
 
@@ -46,7 +46,15 @@ class DescriptorQuery(BaseModel):
     query: str = Field(None, title="Descriptor string", description="SMILES or InChI chemical descriptor", example="c1ccc(cc1)[C@@H](C(=O)O)N")
     # generator: str = Field(None, title="Descriptor generator", description="Program or agent generating the descriptor", example="OpenEye Toolkit")
     matchType: DescriptorMatchType = Field(
-        None, title="Query match type", description="Qualitative graph matching comparison or fingerprint comparison criteria", example="graph-relaxed"
+        None,
+        title="Query match type",
+        description="""Graph matching comparison:
+            graph-strict (atom type, formal charge, aromaticity, bond order, atom/bond stereochemistry),
+            graph-relaxed (atom type, formal charge, bond type),
+            graph-relaxed-stereo (atom type, formal charge, bond type, atom/bond stereochemistry),
+            or fingerprint-similarity (TREE and MACCS)
+        """,
+        example="graph-relaxed",
     )
 
 
@@ -85,7 +93,8 @@ def matchGetQuery(
 
 @router.post("/{descriptorType}", response_model=DescriptorQueryResult, tags=["descriptor"])
 def matchPostQuery(
-    query: DescriptorQuery, descriptorType: DescriptorType = Path(..., title="Descriptor type", description="Type of chemical descriptor (SMILES or InChI)", example="SMILES"),
+    query: DescriptorQuery,
+    descriptorType: DescriptorType = Path(..., title="Descriptor type", description="Type of chemical descriptor (SMILES or InChI)", example="SMILES"),
 ):
 
     logger.info("Got %r %r", descriptorType, query)
